# Pyrinter #
[![Github licence](https://img.shields.io/github/license/hodvak/pyrinter)](https://github.com/hodvak/pyrinter/blob/master/LICENSE)
## What is it? ##
Pyrinter (python printer adapter) is a free open source python package for physical printers use.